import { ActionRow } from "components-jsx/ActionRow";
import { Button } from "components-jsx/Button";
import { ComponentMessage } from "components-jsx/ComponentMessage";
import { Container } from "components-jsx/Container";
import { Divider } from "components-jsx/Divider";
import { TextDisplay } from "components-jsx/TextDisplay";
import { ButtonStyles, User as OUser } from "oceanic.js";
import { Response } from "~/types";
import { User } from "./User";
import { Constants } from "~/Constants";
import { ApplicationContent } from "./ApplicationContent";

export function PendingApplicationMessage(props: {
	id: string;
	user: OUser;
	response: Response;
	locked?: boolean;
}) {
	const { id, user, response } = props;
	const locked = props.locked || false;
	return (
		<ComponentMessage>
			<TextDisplay>{"<@&1375617676139040909>"}</TextDisplay>
			<Container
				accentColor={
					!locked ? Constants.COLORS.NEW_REQ : Constants.COLORS.YELLOW
				}
			>
				<TextDisplay>## New join request</TextDisplay>
				<Divider />
				<User user={user} />
				<Divider />
				<ApplicationContent response={response} />
				<Divider />
				<TextDisplay>
					### Details
					<br />
					{response.details}
				</TextDisplay>
				<Divider />
				<ActionRow>
					<Button
						style={ButtonStyles.SUCCESS}
						customID={`accept-${id}`}
						emoji={{
							name: "blobcatgreen",
							id: "1375806000312881233"
						}}
						disabled={locked}
					>
						Accept
					</Button>
					<Button
						style={ButtonStyles.SUCCESS}
						customID={`accept-friend-${id}`}
						emoji={{
							name: "blobcatgreen",
							id: "1375806000312881233"
						}}
						disabled={locked}
					>
						Accept + Friend
					</Button>
				</ActionRow>
				<ActionRow>
					<Button
						style={ButtonStyles.DANGER}
						customID={`reject-${id}`}
						emoji={{
							name: "blobcatred",
							id: "1375806202470203513"
						}}
						disabled={locked}
					>
						Deny
					</Button>
					<Button
						style={ButtonStyles.DANGER}
						customID={`reject-ban-${id}`}
						emoji={{
							name: "BAN",
							id: "1375806319621046313"
						}}
						disabled={locked}
					>
						Deny + Ban
					</Button>
				</ActionRow>
				<ActionRow>
					<Button
						style={ButtonStyles.SECONDARY}
						customID={`interview-${id}`}
						emoji={{
							name: "💬"
						}}
					>
						Interview
					</Button>
					<Button
						style={ButtonStyles.SECONDARY}
						customID={`${locked ? "un" : ""}lock-${id}`}
						emoji={{
							name: "🔑"
						}}
					>
						{!locked ? "Lock" : "Unlock"}
					</Button>
				</ActionRow>
			</Container>
		</ComponentMessage>
	);
}
